|milwrm_logo|

Multiplex Image Labeling With Regional Morphology
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

|Latest Version|

Consensus tissue region identification from multiplex molecular image data for digital pathology

Install from PyPI:
^^^^^^^^^^^^^^^^^^
.. code:: bash

   pip install MILWRM

Or compile from source:
^^^^^^^^^^^^^^^^^^^^^^^
.. code:: bash

   git clone https://github.com/codyheiser/MILWRM.git
   cd MILWRM
   python setup.py install

See the |tutorials|_ directory for Jupyter notebooks detailing usage of `MILWRM`

Full documentation is available at |codyheiser.github.io/MILWRM|_

.. |milwrm_logo| image:: https://github.com/codyheiser/MILWRM/blob/main/docs/milwrm_logo.jpg

.. |Latest Version| image:: https://img.shields.io/pypi/v/MILWRM
   :target: https://pypi.python.org/pypi/MILWRM/

.. |tutorials| replace:: ``tutorials``
.. _tutorials: tutorials

.. |codyheiser.github.io/MILWRM| replace:: ``codyheiser.github.io/MILWRM``
.. _codyheiser.github.io/MILWRM: https://codyheiser.github.io/MILWRM/
